@@ -1,4 +1,4 @@
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 from cubes.activitystream.entities import IActivityStreamAdapter, ActivityStreamPart
 
 class TrackerIActivityStreamAdapter(IActivityStreamAdapter):
