@@ -12,9 +12,10 @@ from logilab.common.date import todate
 from rql import nodes
 
 from cubicweb import ValidationError
+from cubicweb.entity import can_use_rest_path
 from cubicweb.entities import AnyEntity
 from cubicweb.entities.adapters import IUserFriendlyUniqueTogether
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 from cubicweb.utils import CubicWebJsonEncoder
 
 from cubes.iprogress.entities import IProgressAdapter
@@ -24,11 +25,11 @@ class VersionIProgressAdapter(IProgressAdapter):
     __select__ = is_instance('Version')
 
     def progress_info(self):
+        tickets = self.entity.reverse_done_in
         """returns a dictionary describing load and progress of the version"""
-        return {'notestimated': 0,
-                'estimated': 0,
-                'done': 0,
-                'todo': 0 }
+        return {'estimated': len(tickets),
+                'done': len([t for t in tickets if not t.is_open()]),
+                'todo': len([t for t in tickets if t.is_open()])}
 
     def finished(self):
         return self.entity.cw_adapt_to('IWorkflowable').state in self.entity.FINISHED_STATES
@@ -85,7 +86,12 @@ class Version(AnyEntity):
     cw_fetch_unrelated_order = cw_fetch_order
 
     def rest_path(self, use_ext_eid=False):
-        return u'%s/%s' % (self.project.rest_path(), self.num)
+        if can_use_rest_path(self.num) and can_use_rest_path(self.project.name):
+            # url rewritten (see ``tracker.views.TrackerURLRewriter``)
+            return 'project/%s/%s' % (self._cw.url_quote(self.project.name),
+                                      self._cw.url_quote(self.num))
+        else:
+            return super(Version, self).rest_path(use_ext_eid)
 
     @property
     def project(self):
@@ -182,6 +188,11 @@ class VersionIUserFriendlyUniqueTogether(IUserFriendlyUniqueTogether):
     __select__ = IUserFriendlyUniqueTogether.__select__ & is_instance('Version')
     def raise_user_exception(self):
         etype, rtypes = self.exc.args
+        if 'version_of' in self.entity.cw_edited:
+            project_eid = self.entity.cw_edited['version_of']
+            project_name = self._cw.entity_from_eid(project_eid).name
+        else:
+            project_name = self.entity.project.name
         msg = self._cw._('version %(num)s already exists for project %(project)s') % (
-            {'num': self.entity.num, 'project': self.entity.project.name})
+            {'num': self.entity.num, 'project': project_name})
         raise ValidationError(self.entity.eid, dict((col, msg) for col in rtypes))
