@@ -11,7 +11,7 @@ from datetime import datetime
 from cubicweb import ValidationError
 from cubicweb.utils import transitive_closure_of
 from cubicweb.schema import META_RTYPES
-from cubicweb.selectors import is_instance, on_fire_transition
+from cubicweb.predicates import is_instance, on_fire_transition
 from cubicweb.server import hook
 from cubicweb.hooks import notification
 
