@@ -82,12 +82,12 @@ class Version(WorkflowableEntityType):
                                      'add':    ('managers', 'staff', oexpr('client'),),
                                      'delete': ('managers', ),
                                      })
-    todo_by = SubjectRelation('CWUser',
-                              constraints=[RQLConstraint('O in_state ST, ST name "activated"'),
+    assigned_to = SubjectRelation('CWUser',
+                              constraints=[RQLVocabularyConstraint('O in_state ST, ST name "activated"'),
                                            RQLVocabularyConstraint('O in_group G, G name "staff"')],
                               __permissions__ = {
                                   'read':   ('managers', 'users', 'guests'),
-                                  'add':    ('managers',),
+                                  'add':    ('managers', RRQLExpression('S version_of P, P owned_by U')),
                                   'delete': ('managers',),
                                   },
                               description=_('users responsible for this version'))
@@ -178,6 +178,16 @@ class Ticket(WorkflowableEntityType):
                                      'PO identity P OR '
                                      'EXISTS(P uses PO) OR '
                                      'EXISTS(PO subproject_of P)')])
+    assigned_to = SubjectRelation('CWUser',
+                               __permissions__ = {
+                                   'read':   ('managers', 'users', 'guests'),
+                                   'add':    ('managers', RRQLExpression('S concerns P, P owned_by U'),), 
+                                   'delete': ('managers', RRQLExpression('S concerns P, P owned_by U'),),
+                                   },
+                               cardinality='?*',
+                               description=_("user who has to execute this ticket"),
+                               constraints=[RQLVocabularyConstraint(
+                                     'O in_state ST, ST name "activated"')])
 
 
 
