@@ -7,7 +7,7 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.web import uicfg
+from cubicweb.web.views import uicfg
 from cubicweb.web.views.urlrewrite import (
     SimpleReqRewriter, SchemaBasedRewriter, rgx, build_rset)
 
