@@ -7,7 +7,7 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 from cubicweb.web.facet import RelationFacet, AttributeFacet, DateRangeFacet
 
 class TicketConcernsFacet(RelationFacet):
