@@ -13,8 +13,8 @@ from cubicweb.view import EntityView, EntityAdapter
 from cubicweb.predicates import (objectify_predicate, is_instance, multi_lines_rset,
                                  score_entity)
 from cubicweb import tags, uilib
-from cubicweb.web import uicfg, component, action
-from cubicweb.web.views import primary, baseviews, ibreadcrumbs
+from cubicweb.web import component, action
+from cubicweb.web.views import uicfg, primary, baseviews, ibreadcrumbs
 
 _pvs = uicfg.primaryview_section
 
