@@ -15,8 +15,8 @@ from cubicweb import tags
 from cubicweb.schema import display_name
 from cubicweb.predicates import is_instance, score_entity
 from cubicweb.view import EntityView, StartupView, EntityAdapter
-from cubicweb.web import uicfg, component, action
-from cubicweb.web.views import (baseviews, tabs, tableview,
+from cubicweb.web import component, action
+from cubicweb.web.views import (uicfg, baseviews, tabs, tableview,
                                 xmlrss, navigation, ibreadcrumbs)
 
 from cubes.iprogress import views as iprogress
